//
//  PlayerViewController.swift
//  Data
//

import UIKit
import AVFoundation
import AVKit

class PlayerViewController: UIViewController {

    var playerViewController : AVPlayerViewController?
    
    override func viewDidLoad() {
        super.viewDidLoad()

        // Do any additional setup after loading the view.
        
        guard let url = Bundle.main.url(forResource: "sample", withExtension: "mov") else {
            return
        }
        
        // 動画プレイヤーを初期化
        playerViewController = AVPlayerViewController()
        // 再生する動画を指定
        let player = AVPlayer(url: url)
        playerViewController?.player = player
        // コントローラーを表示しない
        playerViewController?.showsPlaybackControls = true
        
        // サイズを指定して画面に追加
        playerViewController?.view.frame = CGRect(x:40, y:120, width:240, height:180)
        // アスペクト比を保ち枠内に収まるように
        playerViewController?.player?.externalPlaybackVideoGravity = AVLayerVideoGravity.resizeAspect
        view.addSubview((playerViewController?.view)!)
        
        // 動画の再生が終わった際の処理
        NotificationCenter.default.addObserver(self, selector: #selector(PlayerViewController.movieFinished(_:)), name: NSNotification.Name.AVPlayerItemDidPlayToEndTime, object: nil)
    }
    
    // 再生
    @IBAction func onPlay(_ sender: Any) {
        self.playerViewController?.player?.play()
    }
    
    // 停止
    @IBAction func onStop(_ sender: Any) {
        self.playerViewController?.player?.pause()
    }
    
    // 音量
    @IBAction func onVolumeChange(_ sender: Any) {
        if let slider = sender as? UISlider {
            self.playerViewController?.player?.volume = slider.value
        }
    }
    
    // 動画の再生が終わった際にラベルを表示
    @objc func movieFinished(_ sndeer:Any) {
        let label = UILabel(frame: CGRect(x:0, y:0, width:100, height:50))
        label.text = "fin"
        label.textColor = UIColor.white
        label.textAlignment = NSTextAlignment.center
        label.backgroundColor = UIColor.black
        label.center = (self.playerViewController?.contentOverlayView?.center)!
        self.playerViewController?.contentOverlayView?.addSubview(label)
    }
    
    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
        // Dispose of any resources that can be recreated.
    }
    
}
