//
//  ImagePickerViewController.swift
//  Device
//
//

import UIKit
import AVFoundation

class ImagePickerViewController: UIViewController , UIActionSheetDelegate, UINavigationControllerDelegate, UIImagePickerControllerDelegate {

    @IBOutlet var imageView: UIImageView!
    
    override func viewDidLoad() {
        super.viewDidLoad()

        // Do any additional setup after loading the view.
    }

    // アクションシートでイメージピッカーの種類を選択
    @IBAction func showPicker(_ sender: Any) {
        var actionSheet = UIAlertController(title: "選択してください", message: nil, preferredStyle: .actionSheet)
        func handler(act:UIAlertAction!) {
            var sourceType : UIImagePickerControllerSourceType?
            switch (act.title!) {
                case "Camera":
                    // カメラで画像を取得
                    sourceType = UIImagePickerControllerSourceType.camera
                case "Photo Album":
                    // フォトライブラリから画像を取得
                    sourceType = UIImagePickerControllerSourceType.photoLibrary
                case "Saved Photos":
                    // カメラで撮影した画像から取得
                    sourceType = UIImagePickerControllerSourceType.savedPhotosAlbum
                default:
                    break
            }
            
            // 選択したものが利用できなければ処理を中断
            if !UIImagePickerController.isSourceTypeAvailable(sourceType!) { return }
            
            // 種類を指定してピッカーを表示
            let picker : UIImagePickerController = UIImagePickerController()
            picker.sourceType = sourceType!
            picker.allowsEditing = true
            picker.delegate = self
            
            // 種類を指定してピッカーを表示
            self.present(picker, animated: true, completion: nil)
        }
        
        actionSheet.addAction(UIAlertAction(title: "Camera", style: .default, handler: handler))
        actionSheet.addAction(UIAlertAction(title: "Photo Album", style: .default, handler: handler))
        actionSheet.addAction(UIAlertAction(title: "Saved Photos", style: .default, handler: handler))
        actionSheet.addAction(UIAlertAction(title: "Cancel", style: .cancel, handler: nil))
        self.present(actionSheet, animated: true, completion: nil)
    }
    
    @IBAction func savePhoto(_ sender: Any) {
        if imageView.image == nil { return }
        // 画像データ取得
        if let image : UIImage = imageView.image{
            UIImageWriteToSavedPhotosAlbum(image, self, #selector(ImagePickerViewController.image(_:didFinishSavingWithError:contextInfo:)), nil)
        }
        
    }
    
    
    // 画像保存時のセレクタ
    @objc func image(_ image: UIImage, didFinishSavingWithError error: NSError!, contextInfo: UnsafeMutableRawPointer) {
        
        var message : String?
        if (error == nil) {
            message = "保存しました"
        } else {
            message = "保存に失敗しました"
        }
        
        // 処理の完了時にはアラートを出す
        let alert = UIAlertController(title: message!, message: "", preferredStyle: .alert)
        // OKボタンalert加
        let okAction = UIAlertAction(title: "OK", style: .default, handler: nil)
        alert.addAction(okAction)
        // 表示
        present(alert,animated: true)
    }

    // 画像選択時の処理
    func imagePickerController(_ picker: UIImagePickerController,
                               didFinishPickingMediaWithInfo info: [String : Any]) {
        
        // 選択した画像を画面に表示
        if let image : UIImage = info[UIImagePickerControllerOriginalImage] as? UIImage{
            imageView.image  = image
        }
        // ピッカーを閉じる
        self.dismiss(animated: true, completion: nil)
    }
    
    // キャンセル時の処理
    func imagePickerControllerDidCancel(_ picker: UIImagePickerController) {
        // ピッカーを閉じる
        self.dismiss(animated: true, completion: nil)
    
    }
    

    /*
    // MARK: - Navigation

    // In a storyboard-based application, you will often want to do a little preparation before navigation
    override func prepareForSegue(segue: UIStoryboardSegue, sender: AnyObject?) {
        // Get the new view controller using segue.destinationViewController.
        // Pass the selected object to the new view controller.
    }
    */

}
