//
//  BackgroundViewController.swift
//  Net
//
//

import UIKit

class BackgroundViewController: UIViewController, URLSessionDelegate, URLSessionDownloadDelegate{

    override func viewDidLoad() {
        super.viewDidLoad()

        // Do any additional setup after loading the view.
        
        
    }

    @IBAction func onBackGround(_ sender: Any) {
        
        // URLを指定してNSURLオブジェクトを生成
        let str : String = "http://www.apple.com/education/docs/Apple_ID_Parent_Guide.pdf"
        let url : URL = URL(string: str)!
        
        let identifier : String = "sample"
        
        // 詳細を指定 バックグラウンド通信を利用
        let config : URLSessionConfiguration = URLSessionConfiguration.background(withIdentifier: identifier)
        // キャリア回線を利用
        config.allowsCellularAccess = true
        // 状況に応じて優先度を下げる
        config.isDiscretionary = true
        
        // URLSessionオブジェクトを生成
        let session = Foundation.URLSession(configuration: config, delegate: self, delegateQueue: OperationQueue())
        
        let task : URLSessionDownloadTask = session.downloadTask(with: url)
        // 通信を開始
        task.resume()
    }
    
    // ダウンロード中の処理
    func urlSession(_ session: URLSession,
                    downloadTask: URLSessionDownloadTask,
                    didWriteData bytesWritten: Int64,
                    totalBytesWritten: Int64,
                    totalBytesExpectedToWrite: Int64)
    {
        print(totalBytesWritten)
        DispatchQueue.global().async {
            DispatchQueue.main.async {
            // ダウンロードするトータルのサイズに対する現在ダウンロードしたサイズの割合
            let progress : Float = Float(totalBytesWritten)/Float(totalBytesExpectedToWrite)
            print(progress)
            }}
    }
    
    // ダウンロード完了時の処理
    func urlSession(_ session: URLSession,
                    downloadTask: URLSessionDownloadTask,
                    didFinishDownloadingTo location: URL)
    {
        // ダウンローしたデータを保存
        let filename: String = "sample.pdf"
        let manager = FileManager.default
        let docURL = try! manager.url(for: .documentDirectory, in:.userDomainMask, appropriateFor:nil, create:true)
        let filePathURL: URL = docURL.appendingPathComponent(filename)//URLByAppendingPathComponent(filename)
        
        print(filePathURL)
        
        // ファイルがすでに存在する場合は削除
        do{
            try manager.removeItem(at: filePathURL)
        }catch{}
        // 保存
        do{
            try manager.moveItem(at: location, to: filePathURL)
        }catch{}
    }
    
    func urlSession(_ session: URLSession, task: URLSessionTask, didCompleteWithError error: Error?) {
        
        // エラーがあれば出力
        if error != nil {
            print(error ?? "")
            return
        }
        // NSURLSessionを終了
        session.finishTasksAndInvalidate()
    }
    
    // バックグラウンドでのHTTP通信時の処理
    func urlSessionDidFinishEvents(forBackgroundURLSession session: URLSession)
    {
        // AppDelegateを取得
        let delegate : AppDelegate = UIApplication.shared.delegate as! AppDelegate
        // ハンドラを取得
        if (delegate.handler != nil) {
            var _:Void = delegate.handler
            delegate.handler = nil
        }
        print("バックグラウンドセッション終了")
    }
    
    
    private func URLSession(session: URLSession,
                    didReceiveChallenge challenge: URLAuthenticationChallenge,
                    completionHandler: @escaping (URLSession.AuthChallengeDisposition,
        URLCredential?) -> Void)
    {
        print("バックグラウンド イベント終了")
    }
    
    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
        // Dispose of any resources that can be recreated.
    }
    

    /*
    // MARK: - Navigation

    // In a storyboard-based application, you will often want to do a little preparation before navigation
    override func prepareForSegue(segue: UIStoryboardSegue, sender: AnyObject?) {
        // Get the new view controller using segue.destinationViewController.
        // Pass the selected object to the new view controller.
    }
    */

}
