//
//  JsonViewController.swift
//  Net
//
//

import UIKit

class JsonViewController: UIViewController {

    override func viewDidLoad() {
        super.viewDidLoad()

        // Do any additional setup after loading the view.
        
        //  RANDOM USER GENERATORのAPIにアクセスし、APIの結果をJSONで取得
        let str : String = "https://randomuser.me/api"
        let url : URL = URL(string: str)!
        
        // URLRequestを生成してJSONのデータを取得
        let request: URLRequest = URLRequest(url:url)
        let session = URLSession.shared
        let task : URLSessionDataTask = session.dataTask(with: request, completionHandler: {(data, response, error) in
            
            // APIからの戻り値がなければ処理を終了
            guard let data = data else{ return }
            
            // エラーがあれば表示
            if(error != nil) {
                print(error ?? "")
                return
            }
            do{
                // JSONDecoderクラスのインスタンスを生成
                let decoder = JSONDecoder()
                // JSONを解析して作成した構造体の通りにマッピング
                let resultList = try decoder.decode(ResultUserList.self, from: data)
                print(resultList)
                
                // JSONを解析した後、User構造体にマッピングされたデータを取り出す
                for user in resultList.results {
                    print(user.gender)
                    print(user.name.title)
                    print(user.location.postcode)
                    print(user.email)
                }
            }catch{
                print("JSONの解析でエラーが起きました")
            }
            /*
            do {
                // JSONを辞書オブジェクトに変換
                let jsonResult = try JSONSerialization.jsonObject(with: data, options: JSONSerialization.ReadingOptions.mutableContainers) as! NSMutableDictionary
                
                // resultsキー以下を辞書として取得
                if let resultsData = jsonResult["results"] as? [NSMutableDictionary] {
                    // resultsキー以下を解析
                    for item in resultsData {
                        // nameキー以下を取得
                        if let name = item["name"] {
                            print(name)
                        }
                        // locationキー以下を取得
                        if let location = item["location"] {
                            print(location)
                        }
                    }
                }
            } catch {
                print("JSONの解析でエラーが起きました")
            }
            */
        })
        task.resume()
    }

    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
        // Dispose of any resources that can be recreated.
    }
}

// resultsを格納する構造体
struct ResultUserList:Codable{
    let results : [User]
}

// ユーザー情報を格納す構造体
struct User: Codable  {
    let gender: String
    
    let name: Name
    struct Name: Codable  {
        let title: String
        let first: String
        let last: String
    }
    
    let location: Location
    struct Location: Codable  {
        let street: String
        let city: String
        let state: String
        let postcode: Int
    }
    
    let email: String
    
    let login: Login
    struct Login: Codable {
        let username: String
        let password: String
        let salt: String
        let md5: String
        let sha1: String
        let sha256: String
    }
    
    let dob: String
    let registered: String
    let phone: String
    let cell: String
    
    let id: Id
    struct Id: Codable {
        let name: String
        let value: String
    }
    
    let picture: Picture
    struct Picture: Codable {
        let large: String
        let medium: String
        let thumbnail: String
    }
    
    let nat: String
}


