//
//  DatePickerViewController.swift
//  UI
//
//

import UIKit

class DatePickerViewController: UIViewController {

    var datePicker : UIDatePicker?
    
    override func viewDidLoad() {
        super.viewDidLoad()

        // Do any additional setup after loading the view.
        
        let items : Array<String> = ["月日時分", "年月日", "時分", "タイマー"]
        
        let segment : UISegmentedControl = UISegmentedControl(items: items)
        
        segment.frame = CGRect(x:10, y:80, width:300, height:30)
        segment.tintColor = UIColor.gray
        segment.isMomentary = true
        
        self.view.addSubview(segment)
        
        segment.addTarget(self, action: #selector(DatePickerViewController.onSelect(_:)), for: UIControlEvents.valueChanged)
        
        
        // 初期化処理
        datePicker = UIDatePicker()
        datePicker!.center = self.view.center
        // 年月日の選択
        datePicker!.datePickerMode = UIDatePickerMode.date
        
        // 年月日を指定
        let dateFormatter : DateFormatter = DateFormatter()
        dateFormatter.locale = Locale(identifier: "ja_JP")
        dateFormatter.dateFormat = "yyyy-MM-dd HH:mm:ss"
        let formatterDate : Date = dateFormatter.date(from: "2018-12-01 19:00:00")!
        datePicker!.setDate(formatterDate, animated:false)
        
        // ピッカーの値が変わった際の処理を指定
        datePicker!.addTarget(self, action: #selector(DatePickerViewController.selectDate(_:)), for: UIControlEvents.valueChanged)
        
        self.view.addSubview(datePicker!)
    }

    @objc func selectDate(_ sender:UIDatePicker){
        let picker : UIDatePicker = sender
        
        // フォーマットを指定
        let dateFormatter : DateFormatter = DateFormatter()
        dateFormatter.locale = Locale(identifier: "ja_JP")
        dateFormatter.dateFormat = "yyyy年MM月dd日 HH時mm分"
        // 選択された日付を出力
        print(dateFormatter.string(from: picker.date))
    }
    
    @objc func onSelect(_ sender:UISegmentedControl){
        let seg : UISegmentedControl = sender
        
        switch(seg.selectedSegmentIndex){
            case 0 :
                datePicker!.datePickerMode = UIDatePickerMode.dateAndTime
                datePicker!.minuteInterval = 5
            
            case 1 :
                // 日付選択の形式を指定
                datePicker!.datePickerMode = UIDatePickerMode.date
                let minDateString = "2018-08-01"
                let maxDateString = "2018-09-01"
                
                // フォーマットを指定
                let dateFormatter : DateFormatter = DateFormatter()
                dateFormatter.dateFormat = "yyyy-MM-dd"
                
                // 日付の最小値を指定
                datePicker!.minimumDate = dateFormatter.date(from: minDateString)
                // 日付の最大値を指定
                datePicker!.maximumDate = dateFormatter.date(from: maxDateString)
            
            case 2:
                // 10分間隔
                datePicker!.datePickerMode = UIDatePickerMode.time
                datePicker!.minuteInterval = 10
            
            case 3:
                datePicker!.datePickerMode = UIDatePickerMode.countDownTimer
                datePicker!.countDownDuration = 5*60
            
            default:
                break
        }
    }
    
    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
        // Dispose of any resources that can be recreated.
    }
    

    /*
    // MARK: - Navigation

    // In a storyboard-based application, you will often want to do a little preparation before navigation
    override func prepareForSegue(segue: UIStoryboardSegue, sender: AnyObject?) {
        // Get the new view controller using segue.destinationViewController.
        // Pass the selected object to the new view controller.
    }
    */

}
