//
//  CollectionSectionViewController.swift
//  ViewControllers
//

import UIKit

private let reuseIdentifier = "Cell"
private let reuseIdentifierHeader = "Header"

class CollectionSectionViewController: UICollectionViewController {

    var sections = [String]()
    var menuList = [[String]]()
    
    override func viewDidLoad() {
        super.viewDidLoad()

        // Uncomment the following line to preserve selection between presentations
        // self.clearsSelectionOnViewWillAppear = false

        // Register cell classes
        //self.collectionView!.register(UICollectionViewCell.self, forCellWithReuseIdentifier: reuseIdentifier)
        
        // セルを登録
        let cellNib = UINib(nibName: "ItemCollectionCell", bundle: nil)
        self.collectionView!.register(cellNib, forCellWithReuseIdentifier: reuseIdentifier)
        
        // ヘッダを登録
        let headerNib = UINib(nibName: "ItemCollectionHeader", bundle: nil)
        self.collectionView?.register(headerNib, forSupplementaryViewOfKind: UICollectionElementKindSectionHeader, withReuseIdentifier: reuseIdentifierHeader)
        
        // Do any additional setup after loading the view.
        // セクションの見出し
        sections = ["section1", "section2", "section3"]
        // セルに表示するデータ
        menuList.append(Array(1...10).flatMap({"\($0)"}))
        menuList.append(Array(1...20).flatMap({"\($0)"}))
        menuList.append(Array(1...30).flatMap({"\($0)"}))
        
        self.collectionView?.backgroundColor = UIColor.black
        
        // コレクションのフローの詳細を指定
        let flowLayout : UICollectionViewFlowLayout = UICollectionViewFlowLayout()
        // セルのサイズ
        flowLayout.itemSize = CGSize(width:50.0, height:50.0)
        // 縦、横のスペース
        flowLayout.minimumInteritemSpacing = 10.0
        flowLayout.minimumLineSpacing = 12.0
        // ヘッダのサイズ
        flowLayout.headerReferenceSize = CGSize(width:self.view.bounds.width, height:20.0)
        // セクションのpadding
        flowLayout.sectionInset = UIEdgeInsets(top: 10, left: 5, bottom: 10, right: 5)
        // スクロールの方向
        flowLayout.scrollDirection = UICollectionViewScrollDirection.vertical
        // コレクションへ反映
        self.collectionView?.collectionViewLayout = flowLayout
    }

    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
        // Dispose of any resources that can be recreated.
    }

    /*
    // MARK: - Navigation

    // In a storyboard-based application, you will often want to do a little preparation before navigation
    override func prepare(for segue: UIStoryboardSegue, sender: Any?) {
        // Get the new view controller using [segue destinationViewController].
        // Pass the selected object to the new view controller.
    }
    */

    // MARK: UICollectionViewDataSource

    override func numberOfSections(in collectionView: UICollectionView) -> Int {
        // #warning Incomplete implementation, return the number of sections
        return sections.count
    }


    override func collectionView(_ collectionView: UICollectionView, numberOfItemsInSection section: Int) -> Int {
        // #warning Incomplete implementation, return the number of items
        return menuList[section].count
    }
    
    // ヘッダ／フッタのデータを指定
    override func collectionView(_ collectionView: UICollectionView,
                                 viewForSupplementaryElementOfKind kind: String,
                                 at indexPath: IndexPath) -> UICollectionReusableView
    {
        // ヘッダの場合
        if (kind == "UICollectionElementKindSectionHeader") {
            // ヘッダを取得
            let header = collectionView.dequeueReusableSupplementaryView(ofKind: UICollectionElementKindSectionHeader, withReuseIdentifier: reuseIdentifierHeader, for: indexPath) as! ItemCollectionHeader
            header.label.text = sections[indexPath.section]
            return header
            
        }
        // ヘッダ以外は表示しないので空のオブジェクトを返す
        return UICollectionReusableView()
    }
    
    // コレクションのセルにデータを指定
    override func collectionView(_ collectionView: UICollectionView, cellForItemAt indexPath: IndexPath) -> UICollectionViewCell {
        // セルを生成し、○番目に相当するデータを表示
        let cell = collectionView.dequeueReusableCell(withReuseIdentifier: reuseIdentifier, for: indexPath) as? ItemCollectionCell
        cell?.label.text = menuList[indexPath.section][indexPath.row]
        cell?.backgroundColor = UIColor.white
        return cell!
    }

    // MARK: UICollectionViewDelegate

    /*
    // Uncomment this method to specify if the specified item should be highlighted during tracking
    override func collectionView(_ collectionView: UICollectionView, shouldHighlightItemAt indexPath: IndexPath) -> Bool {
        return true
    }
    */

    /*
    // Uncomment this method to specify if the specified item should be selected
    override func collectionView(_ collectionView: UICollectionView, shouldSelectItemAt indexPath: IndexPath) -> Bool {
        return true
    }
    */

    /*
    // Uncomment these methods to specify if an action menu should be displayed for the specified item, and react to actions performed on the item
    override func collectionView(_ collectionView: UICollectionView, shouldShowMenuForItemAt indexPath: IndexPath) -> Bool {
        return false
    }

    override func collectionView(_ collectionView: UICollectionView, canPerformAction action: Selector, forItemAt indexPath: IndexPath, withSender sender: Any?) -> Bool {
        return false
    }

    override func collectionView(_ collectionView: UICollectionView, performAction action: Selector, forItemAt indexPath: IndexPath, withSender sender: Any?) {
    
    }
    */

}
