//
//  EditTableViewController.swift
//  VC
//
//

import UIKit

class EditTableViewController: UITableViewController
{
    
    let kCellIdentifier = "CellIdentifier"
    var items: Array<String> = Array<String>()
    var editButton : UIBarButtonItem?
    
    override func viewDidLoad() {
        super.viewDidLoad()
        
        self.tableView = UITableView(frame: self.view.bounds, style: UITableViewStyle.grouped)
        
        items = ["Menu1", "Menu2", "Menu3", "Menu4", "Menu5", "Menu6"]
        
        // ナビゲーションアイテムの右側に編集ボタンを設置
        editButton = UIBarButtonItem(title: "編集", style: UIBarButtonItemStyle.plain, target: self, action: #selector(EditTableViewController.selToEdit(_:)))
        self.navigationItem.rightBarButtonItem = editButton
    }
    
    @objc func selToEdit(_ sender: Any){
        // 編集可能ならば編集不可に
        if(self.tableView.isEditing){
            editButton!.title = "編集"
            self.setEditing(false, animated: true)
        }else{
            // 編集不可ならば編集可能に
            editButton!.title = "完了"
            self.setEditing(true, animated: true)
        }
    }
    
    // Override to support conditional editing of the table view.
    // セル単位での編集可否を指定
    override func tableView(_ tableView: UITableView, canEditRowAt indexPath: IndexPath) -> Bool {
        // Return NO if you do not want the specified item to be editable.
        // 0番目のセルは編集を許可しない
        if indexPath.row==0 { return false }
        return true
    }
    
    override func setEditing(_ editing: Bool, animated: Bool) {
        // テーブルの編集中はバックボタンを表示しない
        self.navigationItem.setHidesBackButton(editing, animated: animated)
        if(editing){
            let newIndexPath = IndexPath(row: items.count, section: 0)
            items.append("登録")
            self.tableView.insertRows(at: [newIndexPath], with: UITableViewRowAnimation.fade)
        }else{
            let indexPath = IndexPath(row: items.count-1, section: 0)
            items.remove(at: indexPath.row)
            self.tableView.deleteRows(at: [indexPath], with: UITableViewRowAnimation.fade)
        }
        super.setEditing(editing, animated: animated)
    }
    
    // テーブルの編集形式を指定
    override func tableView(_ tableView: UITableView,
                            editingStyleForRowAt indexPath: IndexPath) -> UITableViewCellEditingStyle {
        // 最後のセルは挿入
        if items.count == indexPath.row+1 {
            return UITableViewCellEditingStyle.insert
        }
        // それ以外は削除
        else{
            return UITableViewCellEditingStyle.delete
        }
    }
    
    // テーブルを編集
    override func tableView(_ tableView: UITableView, commit editingStyle: UITableViewCellEditingStyle, forRowAt indexPath: IndexPath) {
        
        if (editingStyle == UITableViewCellEditingStyle.delete) {
                items.remove(at: indexPath.row)
            // Delete the row from the data source
            // 削除
                self.tableView.deleteRows(at: [indexPath], with: UITableViewRowAnimation.fade)
        }
            else if (editingStyle == UITableViewCellEditingStyle.insert) {
            // Create a new instance of the appropriate class, insert it into the array, and add a new row to the table view
            // 挿入
                items.insert("Menu7", at: items.count-1)
                self.tableView.insertRows(at: [indexPath], with: UITableViewRowAnimation.fade)
        }
    }
    
    // テーブルの編集可否を指定
    override func tableView(_ tableView: UITableView, canMoveRowAt indexPath: IndexPath) -> Bool 
    {
        // Return NO if you do not want the item to be re-orderable.
        // 最初のセルは移動不可
        if indexPath.row==0 { return false }
        // それ以外のセルは移動可能
        return true
    }
    
    // テーブルのセルを移動
    override func tableView(_ tableView: UITableView, moveRowAt fromIndexPath: IndexPath, to: IndexPath)
    {
        print("\(fromIndexPath.row)番地から\(to.row)番地に移動しました")
    }
    
    override func tableView(_ tableView: UITableView,
                            heightForRowAt indexPath: IndexPath) -> CGFloat {
            return 50
    }
    
    override func tableView(_ tableView: UITableView,
                            numberOfRowsInSection section: Int) -> Int {
            return items.count
    }
    
    override func tableView(_ tableView: UITableView, cellForRowAt indexPath: IndexPath) -> UITableViewCell {
            //テーブルのセルの生成(8)
            var cell = tableView.dequeueReusableCell(withIdentifier: kCellIdentifier)
            if cell == nil {
                cell = UITableViewCell(style: UITableViewCellStyle.default,
                    reuseIdentifier: kCellIdentifier)
            }
            let cellTitle = items[indexPath.row]
            cell!.textLabel?.text = cellTitle
            return cell!
    }
    
    override func tableView(_ tableView: UITableView,
                            didSelectRowAt indexPath: IndexPath){
        /*
        var multitouchViewController = MultitouchViewController(nibName : "MultitouchViewController", bundle : nil)
        //self.navigationController.pushViewController(textFieldViewController, animated: true)
        self.navigationController?.pushViewController(multitouchViewController, animated: true)
        */
    }
    
    
    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
        // Dispose of any resources that can be recreated.
    }
}
